From 19032bc0a2988e48265bf7f003a7cfaf0946a01d Mon Sep 17 00:00:00 2001
From: Luis Fernandes <zipleen@gmail.com>
Date: Sat, 28 Apr 2018 12:35:23 +0100
Subject: [PATCH] change function of deinterlace to specify which deinterlace
 mode and filter we want to use

---
 include/vlc/libvlc_media_player.h |  5 ++++-
 lib/video.c                       | 32 +++++++++++++++++++++++---------
 2 files changed, 27 insertions(+), 10 deletions(-)

diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index 20b220448b..a82f70f5e7 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -1419,9 +1419,12 @@ int libvlc_video_take_snapshot( libvlc_media_player_t *p_mi, unsigned num,
  * Enable or disable deinterlace filter
  *
  * \param p_mi libvlc media player
- * \param psz_mode type of deinterlace filter, NULL to disable
+ * \param deinterlace deinterlace mode -1:auto (default), 0: disabled, 1: enabled
+ * \param psz_mode type of deinterlace filter, NULL to default
+ * \version LibVLC 4.0.0 and later
  */
 LIBVLC_API void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi,
+                                                  int deinterlace,
                                                   const char *psz_mode );
 
 /**
diff --git a/lib/video.c b/lib/video.c
index 035cc0ebf1..656c207835 100644
--- a/lib/video.c
+++ b/lib/video.c
@@ -663,28 +663,42 @@ end:
 }
 
 /******************************************************************************
- * libvlc_video_set_deinterlace : enable deinterlace
+ * libvlc_video_set_deinterlace : enable/disable/auto deinterlace and filter
  *****************************************************************************/
-void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi,
+void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi, int deinterlace, 
                                    const char *psz_mode )
 {
+    if (deinterlace < -1 || deinterlace > 1)
+        deinterlace = -1;
+
     if (psz_mode == NULL)
+    {
+        module_config_t *config = config_FindConfig("deinterlace-mode");
+        psz_mode = config ? config->orig.psz : NULL;
+    }
+
+    if (psz_mode == NULL)
+    {
         psz_mode = "";
+        deinterlace = 0;
+    }
+        
     if (*psz_mode
      && strcmp (psz_mode, "blend")    && strcmp (psz_mode, "bob")
      && strcmp (psz_mode, "discard")  && strcmp (psz_mode, "linear")
      && strcmp (psz_mode, "mean")     && strcmp (psz_mode, "x")
      && strcmp (psz_mode, "yadif")    && strcmp (psz_mode, "yadif2x")
-     && strcmp (psz_mode, "phosphor") && strcmp (psz_mode, "ivtc"))
+     && strcmp (psz_mode, "phosphor") && strcmp (psz_mode, "ivtc")
+     && strcmp (psz_mode, "auto"))
         return;
 
-    if (*psz_mode)
+    if (*psz_mode && deinterlace != 0)
     {
         var_SetString (p_mi, "deinterlace-mode", psz_mode);
-        var_SetInteger (p_mi, "deinterlace", 1);
+        var_SetInteger (p_mi, "deinterlace", deinterlace);
     }
     else
-        var_SetInteger (p_mi, "deinterlace", 0);
+        var_SetInteger (p_mi, "deinterlace", deinterlace);
 
     size_t n;
     vout_thread_t **pp_vouts = GetVouts (p_mi, &n);
@@ -692,13 +706,13 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi,
     {
         vout_thread_t *p_vout = pp_vouts[i];
 
-        if (*psz_mode)
+        if (*psz_mode && deinterlace != 0)
         {
             var_SetString (p_vout, "deinterlace-mode", psz_mode);
-            var_SetInteger (p_vout, "deinterlace", 1);
+            var_SetInteger (p_vout, "deinterlace", deinterlace);
         }
         else
-            var_SetInteger (p_vout, "deinterlace", 0);
+            var_SetInteger (p_vout, "deinterlace", deinterlace);
         vlc_object_release (p_vout);
     }
     free (pp_vouts);
-- 
2.15.1 (Apple Git-101)

